package com.zerog.ia.customcode;

import com.zerog.ia.api.pub.*;
import java.io.*;

/**
 * IsRoot.java
 *
 * This custom code rule checks to see if the user is root or not on a UNIX system.
 * It checks the JVM property for user name, checks 'whoami', and checks 'groups'. If either one of these
 * check is true then the user is root.
 * The return value is true or false.
 *
 */
public class IsRoot extends CustomCodeRule {

	/* (non-Javadoc)
	 * @see com.zerog.ia.api.pub.CustomCodeRule#evaluateRule()
	 */
	public boolean evaluateRule() {

		boolean check1 = false;
		boolean check2 = false;
		boolean check3 = false;

		check1 = ExecuteJVMCommand("prop.user.dir");
		check2 = ExecuteUNIXCommand("whoami");
		check3 = ExecuteUNIXCommand("groups");

		//System.out.println("check1 is " + check1);
		//System.out.println("check2 is " + check2);
		//System.out.println("check3 is " + check3);

		if ( check1 || check2 || check3)
			return true;
		else
			return false;
	}

	private boolean ExecuteJVMCommand( String executeString )
	{
		String root = ruleProxy.substitute("$prop.user.name$");
		//System.out.println("Check1: user name is " + root);
		if ( root.equalsIgnoreCase("root"))
			return true;
		else
			return false;
	}

	private boolean ExecuteUNIXCommand ( String executeString )
	{
		boolean isroot = false;
		try
			{
			  // Set up the command to run.
			   //System.out.println("ExecuteCommand: About to execute: "+executeString );
			   final Process p = Runtime.getRuntime().exec(executeString);

			   // Intialize StringWriters that capture the output from the command
			   final StringWriter errWriter = new StringWriter();
			   final StringWriter outWriter = new StringWriter();

			   // Launch a thread to capture the Standard Error Output of the Command
			   Thread thread = new Thread()
			   {
				  public void run()
				  {
					 InputStream err = p.getErrorStream();
					 int c;
					 try
					 {
						while ((c = err.read()) >= 0)
						{
						   errWriter.write(c);
						}
					 }
					 catch (IOException ioe)
					 {
					 	ioe.printStackTrace();
					 }
				  }
			   };

			   // Launch a thread to capture the Standard Output of the Command
			   Thread thread2 = new Thread()
			   {
				  public void run()
				  {
					 InputStream err = p.getInputStream();
					 int c;
					 try
					 {
						while ((c = err.read()) >= 0)
						{
						   outWriter.write(c);
						}
					 }
					 catch (IOException ioe)
					 {
					 		ioe.printStackTrace();
					 }
				  }
			   };

			   thread.start();
			   thread2.start();
			   p.waitFor();

			   // Take the information captured from the string writers, and write them out.
			   String stdErr   = errWriter.toString();
			   String stdOut   = outWriter.toString();

			   // Get the return code
			   String exitCode = new Integer(p.exitValue()).toString();

			   if (stdOut.indexOf("root") != -1)
			   		isroot = true;
			   else
			   		isroot = false;

			   // Print out captured info (for debugging purposes)
			   //System.out.println("ExecuteCommand: StdErr Output: "+stdErr );
			   //System.out.println("ExecuteCommand: StdOut Output: "+stdOut );
			   //System.out.println("ExecuteCommand: Exit Code    : "+exitCode );
			}
			catch(Exception e)
			{
				e.printStackTrace();
			}
			return isroot;
	}
}
